@@ -49,7 +49,6 @@
 
 package com.openexchange.group.servlet.request;
 
-import java.util.Collection;
 import java.util.Map;
 import com.google.common.collect.ImmutableMap;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
@@ -82,11 +81,6 @@ public final class GroupManageActionFactory implements AJAXActionServiceFactory
         this.actions = actions.build();
     }
 
-    @Override
-    public Collection<? extends AJAXActionService> getSupportedServices() {
-        return java.util.Collections.unmodifiableCollection(actions.values());
-    }
-
     @Override
     public AJAXActionService createActionService(final String action) throws OXException {
         return actions.get(action);
